
#ifndef PG_USER_MANAGER_H_
#define PG_USER_MANAGER_H_


int *get_user_passwd();
void pg_validate_passwd (ClutterActor *stage, gchar *password,int is_new);
gboolean pg_save_passwd (gchar *passwd);
gchar *pg_read_passwd_from_file();
gchar *pg_convert_points_to_string(int *array, int array_len);
gchar convert_to_char(int i);
gboolean pg_validate_gesture(gchar *password);
gint countChar(gchar *string, gchar c, int length);

#endif /* PG_USER_MANAGER_H_ */



